<?php
/* --------------------------------------------------------------
   ProductListProviderInterface.inc.php 2018-07-03
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2018 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

/**
 * Interface ProductListProviderInterface
 *
 * @category   System
 * @package    Product
 * @subpackage Interfaces
 */
interface ProductListProviderInterface
{
	/**
	 * Returns a product list item collection by the provided category ID.
	 *
	 * @param IdType $categoryId Category ID.
	 *
	 * @return ProductListItemCollection
	 */
	public function getByCategoryId(IdType $categoryId);
	
	
	/**
	 * Returns all product list items.
	 *
	 * @return ProductListItemCollection
	 */
	public function getAll();
	
	
	/**
	 * Returns a paged list of product items.
	 *
	 * @param \IntType|null $page  (Optional) Offset of resource elements.
	 * @param \IntType|null $limit (Optional) Maximum amount of elements per page.
	 *
	 * @return \ProductListItemCollection
	 */
	public function getAllPaged(IntType $page = null, IntType $limit = null);
	
	
	/**
	 * Filters products records by a given ProductSearchCondition object and returns an array with results.
	 *
	 * @param \ProductSearchCondition $condition    Conditions object for search.
	 * @param \Pager                  $pager        Pager object with page settings to split the results into several
	 *                                              pages.
	 *
	 * @return \ProductListItemCollection
	 */
	public function searchProducts(ProductSearchCondition $condition, Pager $pager);
}